
/* Chrysalide - Outil d'analyse de fichiers binaires
 * types.c - constitution des types communs de JDWP
 *
 * Copyright (C) 2010 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "types.h"


#include <malloc.h>
#include <string.h>


#include "../../../common/endianness.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : blob = flux de données à analyser.                           *
*                pos  = position courante dans ce flux. [OUT]                 *
*                len  = taille totale des données à analyser.                 *
*                str  = chaîne de caractères à la sauce JDWP. [OUT]           *
*                                                                             *
*  Description : Lit une chaîne de caractères UTF-8 au format JDWP.           *
*                                                                             *
*  Retour      : Bilan de l'opération : true en cas de succès, false sinon.   *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool get_jdwp_string(const bin_t *blob, off_t *pos, off_t len, jdwp_string *str)
{
    if (!read_u32(&str->length, blob, pos, len, SRE_BIG))
        return false;

    if ((*pos + str->length) > len)
        return false;

    str->value = (char *)calloc(str->length + 1, sizeof(char));
    memcpy(str->value, &blob[*pos], str->length);

    *pos += str->length;

    return true;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : str = chaîne de caractères à la sauce JDWP.                  *
*                                                                             *
*  Description : Libère de la mémoire une chaîne de caractères UTF-8 JDWP.    *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void free_jdwp_string(jdwp_string *str)
{
    if (str->value != NULL)
        free(str->value);

}
