
/* Chrysalide - Outil d'analyse de fichiers binaires
 * packet.h - prototypes pour la définition des paquets destiné au protocole JDWP
 *
 * Copyright (C) 2010-2012 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _DEBUG_JDWP_PACKET_H
#define _DEBUG_JDWP_PACKET_H


#include <glib-object.h>


#include "jdwp_def.h"
#include "sets/list.h"



#define G_TYPE_JDWP_PACKET               g_jdwp_packet_get_type()
#define G_JDWP_PACKET(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_jdwp_packet_get_type(), GJdwpPacket))
#define G_IS_JDWP_PACKET(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_jdwp_packet_get_type()))
#define G_JDWP_PACKET_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_JDWP_PACKET, GJdwpPacketClass))
#define G_IS_JDWP_PACKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_JDWP_PACKET))
#define G_JDWP_PACKET_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_JDWP_PACKET, GJdwpPacketClass))


/* Répresentation d'un paquet de débogage JDWP (instance) */
typedef struct _GJdwpPacket GJdwpPacket;

/* Répresentation d'un paquet de débogage JDWP (classe) */
typedef struct _GJdwpPacketClass GJdwpPacketClass;



/* Indique le type défini pour un paquet de débogage JDWP. */
GType g_jdwp_packet_get_type(void);

/* Enregistre les différentes tailles dynamiques. */
void g_jdwp_packet_set_sizes(GJdwpPacket *, const jdwp_cmd_vm_id_sizes_reply *);

/* Fournit l'adresse des données de l'en-tête d'un paquet JDWP. */
jdwp_header *g_jdwp_packet_get_header(GJdwpPacket *);

/* Fournit l'adresse des données de l'en-tête d'un paquet JDWP. */
bin_t *g_jdwp_packet_get_hblob(GJdwpPacket *);

/* Recompose l'en-tête d'un paquet à partir de données brutes. */
bool g_jdwp_packet_parse_header(GJdwpPacket *);

/* Définit l'en-tête du paquet pour une requête au format JDWP. */
void g_jdwp_packet_set_request_header(GJdwpPacket *, uint8_t, uint8_t);

/* Définit l'en-tête du paquet pour une réponse au format JDWP. */
void g_jdwp_packet_set_reply_header(GJdwpPacket *, uint32_t, uint16_t);

/* Fournit l'adresse des charges utiles d'un paquet JDWP. */
void g_jdwp_packet_set_payload(GJdwpPacket *, const jdwp_payload *);

/* Fournit l'adresse des charges utiles d'un paquet JDWP. */
jdwp_payload *g_jdwp_packet_get_payload(GJdwpPacket *);

/* Fournit l'adresse des charges utiles d'un paquet JDWP. */
bin_t *g_jdwp_packet_get_pblob(GJdwpPacket *);

/* Recompose une charge utile à partir de ses données brutes. */
bool g_jdwp_packet_parse_payload(GJdwpPacket *, uint8_t, uint8_t);

/* Libère la mémoire occupée par une charge utile de paquet. */
void g_jdwp_packet_free_payload(GJdwpPacket *);

/* Détermine si un paquet est une réponse à un premier paquet. */
bool g_jdwp_packet_is_reply(const GJdwpPacket *, const GJdwpPacket *);



#endif  /* _DEBUG_JDWP_PACKET_H */
